纵横四海 (豆瓣)
Description: 纵横四海电影简介和剧情介绍,纵横四海影评、图片、预告片、影讯、论坛、在线购票
Keywords: 纵横四海,緃横四海,纵横四海影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.174豆瓣电影Top250

# 纵横四海 緃横四海 (1991)

导演: 吴宇森
编剧: 吴宇森 / 高志森 / 秦小珍
主演: 周润发 / 张国荣 / 钟楚红 / 朱江 / 曾江 / 胡枫 / 唐宁 / 邓一君
类型: 剧情 / 喜剧 / 动作 / 犯罪
制片国家/地区: 中国香港
语言: 粤语 / 汉语普通话 / 客家话 / 英语 / 法语
上映日期: 1991-02-02(中国香港)
片长: 108分钟
又名: Once a Thief
IMDb: tt0101020
豆瓣评分
引用
8.8
399372人评价
5星
51.7%
4星
38.2%
3星
9.2%
2星
0.7%
1星
0.2%
好于 99% 动作片
好于 98% 喜剧片
想看 看过
评价:
推荐

## 纵横四海的剧情简介 · · · · · ·

砵仔糕（周润发饰）、阿占（张国荣饰）和红豆（锺楚红饰）均是孤儿，在养父（曾江饰）栽培下成为国际大盗。长大后成了帮他赚钱的艺术品大盗，而三人同时又认了警察（朱江饰）为干爹。
法国巴黎博物馆内，名画《赫林之女仆》被人盗走。与此同时，阿海、阿占和红豆三人以敏捷身手盗得另一幅名画，在与法国大哥交易时得知名画《赫林之女仆》在妖气重重的古堡内，他们在曾江安排下成功地盗取此画之后，反被集团原凶曾江与法国大哥合谋设下陷阱，派人追杀灭口。阿海驾车与杀手快艇相撞……
三人失散，数年后，他们在香港重聚，阿海“瘫痪”住在朱江家里，阿占和红豆已经结婚了。曾江又逼他们去偷画…… ©豆瓣

## 纵横四海的演职员 · · · · · · ( 全部 24 )

- 吴宇森 导演
- 周润发 饰 钵仔糕
- 张国荣 演员
- 钟楚红 演员
- 朱江 演员
- 曾江 演员

## 纵横四海的视频和图片 · · · · · · ( 预告片1 | 添加视频评论 | 图片1098 · 添加 )

## 纵横四海的获奖情况 · · · · · · ( 全部 )

- 第11届香港电影金像奖
- 最佳电影(提名)

- 第11届香港电影金像奖
- 最佳导演(提名)
- 吴宇森

- 第11届香港电影金像奖
- 最佳男主角(提名)
- 周润发

## 喜欢这部电影的人也喜欢 · · · · · ·

  英雄本色

  谍影重重3

  变脸

  暗战

  喋血双雄

  猫鼠游戏

  无间道

  赌神2

  黄飞鸿

  新龙门客栈

我要写短评

## 纵横四海的短评 · · · · · · ( 全部 75468 条 )

热门 / 最新 / 好友

### 2756 有用 战国客 看过 2007-06-24 10:28:16

香港浪漫主义警匪动作片的巅峰之作！那段发哥和红姑的轮椅舞堪称香港电影史上的经典镜头~~

### 1316 有用 石头星 看过 2017-03-26 21:20:20

看过多遍，完全被三个人特有的自身魅力迷住，张国荣用红酒越红外线、三个人的舞蹈，至今都是经典。还有，发哥说，伊拉克不打仗。那是91年。

### 988 有用 高歌 看过 2009-12-20 21:50:01

优雅——除了这两个字，我不知道怎样表达爱慕之情啦。

### 1400 有用 木卫二 看过 2006-08-13 18:51:51

有些电影，就该在那个时代看……

### 2518 有用 伊卡洛斯 看过 2011-03-23 23:04:09

你们都知道我的性格，我喜欢西逛逛，东逛逛，我喜欢流浪，其实爱一个人并不是要跟她一辈子的，我喜欢花， 难道我摘下来你让我闻闻，我喜欢风，难道你让风停下来，我喜欢云，难道你就让云罩着我，我喜欢海，难道我去跳海？

> 更多短评 75468条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 纵横四海的影评 · · · · · · ( 全部 464 条 )

热门 / 最新 / 好友
战国客 2008-10-26 13:18:48

## 风继续吹，我继续爱你们

今天又看了一遍《纵横四海》，还是觉得此片甚为经典。 我一直认为本片的成功在很大程度上依赖于三个主演的出色演出。周润发、钟楚红、张国荣无法阻挡的明星魅力在片中恣意挥洒，穿梭于枪林弹雨却气定神闲，立身在险恶江湖却不离不弃，三个人之间千金难买的情谊着实令人感动。... (展开)
2168 123 197回应 收起
leafalone 2007-08-19 16:09:06

## 小园香径独徘徊 ——《纵横四海》，一部大众电影带给我的小众情怀

录象带，VCD，TV，DVD，在这些所谓代表某个时代的媒体上，有一部电影，并不随着媒介的改变而让我忘却，相比起这些易变的载体来说，它是永恒的，那就是《纵横四海》。 导　演：吴宇森 主　演：周润发、张国荣、钟楚红、朱江、曾江 出品年代：1990 国　　家：中国香港 类　... (展开)
353 30 43回应 收起
陈裸 2008-12-11 13:10:59

## 往事如烟

看《纵横四海》时，不由得为里面的友情和爱情轻微触动。阿占、钵仔糕与红豆开着红色法拉利在巴黎街道上奔驰的样子，实在太快乐，太无忧，太灿烂恣肆。发哥、哥哥和红姑年轻的面容，飞扬明亮，我却禁不住流下泪来。 是的，现在哥哥已入天堂，红姑也早已嫁作商人妇，只... (展开)
286 11 18回应 收起
荷马的玫瑰 2005-10-01 17:44:10

## 当时的他们

听说这是最美的一部“贼”片，不用听说，看也看得到。一部喜剧的贼片，能看得人边笑边唏嘘感叹，实在是观者的幸福。你说，这样黄金的组合，究竟需要多少年，才会再出现？ “其实爱一个人并不是要跟她一辈子的。我喜欢花，难道我摘下来你让我闻闻；我喜欢风，难道你让风停下来... (展开)
189 14 27回应 收起
圣墟 2017-05-11 10:59:52

## 要看香港电影，就绝对不能错过这部片子

“你们都知道我的性格，我喜欢西逛逛，东逛逛，我喜欢流浪，其实爱一个人并不是要跟她一辈子的，我喜欢花，难道我摘下来你让我闻闻，我喜欢风，难道你让风停下来，我喜欢云，难道你就让云罩着我，我喜欢海，难道我去跳海……”这段从发哥口中说出的令人感动的经典台词相信看过... (展开)
91 5 1回应 收起
林微云 2017-05-08 21:34:05

## 【情迷画色】番外08 解密电影《纵横四海》的艺术作品

原创 2017-05-08 林微云 不合逻辑的诗意 本文内容版权归作者林微云（微博@林微云vv）所有，未经作者同意，禁止转载，否则投诉到底。如需转载文章请微博联系。欢迎关注“不合逻辑的诗意”。 当然，欢迎大家转发到朋友圈分享：） 警告：本文多图，请在wifi状态下打开，当然，土... (展开)
89 1 3回应 收起
机器人小小 2010-12-29 16:38:31

## 我是通天大盗，明天看报纸吧

“你们这样做是不会有好结果的，祝你们春梦了无痕” 几近春秋二十载，还有谁沉眠于往 其实是巴黎美景，我却想到一句红墙瓦上海阔天空 我最喜欢的台词当然是张国荣的开场白 “我是通天大盗，明天看报纸吧” 忽然想起重新看张国荣的片，是因为最近读了的灰的【与他共度六... (展开)
140 1 5回应 收起
逆袭的泥巴 2018-08-11 13:33:57

## 这是最好的结局

其实我相信亚Joe一直都爱着红豆的，红豆最后是否还喜欢亚占我不确定，但是我觉得电影的结局是最好的结局。 亚占和亚Joe对爱的表达方式不同，亚占给人的感觉是体贴的，对红豆的照顾是全身心全方位的。亚Joe的对爱意的表达则是，我喜欢你我就捉弄你，搞个恶作剧什么的，没有亚占... (展开)
68 2 9回应 收起
音和 2006-03-22 09:48:02

## 纵横四海

没有看《纵横四海》之前，对它多少是有一点排斥的，很担心这又会是一部俗套的枪战片，更担心张国荣会作为主角的陪衬而在影片经历那些配角套路似的悲惨命运，因为在我看来，这实在是很残忍的事情。 不过还好，整部片子看下来，总算是松了一口气，谢谢《纵横四海》这个江... (展开)
103 11 46回应 收起
starscream 2016-03-07 21:02:08

## 名导 卡司与情怀也难以拯救这部烂片.......

想不到此片竟出自吴导之手，曾看过他的英雄本色1和喋血双雄，被电影中浓浓的侠客情谊所感动，情节引人入胜，人物有血有肉，可以说是经典中的经典。而本片除了发哥与哥哥的卡司阵容，并无特别出彩之处。剧本硬伤，漏洞百出，角色塑造流于表面，性格扁平化严重，连善良警官的出场... (展开)
81 37 31回应 收起

> 更多影评 464篇

添加新讨论

## 讨论区 · · · · · ·

这个片是不是就没有粤语版？ | 来自小炮子子 | 12 回应 | 2022-11-22 20:07:42
二刷 | 来自油炸冰淇淋 | 1 回应 | 2022-11-21 20:21:28
这是个烂片啊 | 来自我最爱毛绒绒了 | 25 回应 | 2022-11-12 20:38:07
《纵横四海》排在172太低了 | 来自星龙发杰 | 3 回应 | 2022-11-06 20:54:53
大家有没有觉得用炸药炸保险柜门那段很扯？ | 来自面豉超人 | 5 回应 | 2022-11-04 22:32:26

> 去这部影片的讨论区（全部161条）

## 关于《纵横四海》的问题 · · · · · · ( 全部17个 )

- 为什么第一次进入有红外线的房间没有红外线？ 2人回答
- 影片开始盗画部分为什么要两个人配合，一个人就够啦？ 7人回答

> 全部17个问题

## 在哪儿看这部电影 · · · · · ·

- 腾讯视频 VIP免费观看

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 179部经典港片 (德拉库拉拉)
- 2013第十六届上海国际电影节影片大全（上） (妖灵妖)
- 中文电影250强总榜（1905——2012） (东方快车)
- 剧情扣人、故事性强、不闷的好电影 (影志)

## 谁在看这部电影 · · · · · ·

- 兔田酱真可爱
  3分钟前 想看
- momo
  16分钟前 想看
- 曾阿卷🍍
  18分钟前 看过

641598人看过 / 151577人想看

订阅纵横四海的评论:
feed: rss 2.0